@@ -228,4 +228,4 @@ def execute(client):
         create_schedules(client, to_be_created)
     updated, to_be_deleted = retrieve_updated_schedules(client)
     update_schedules(client, updated, to_be_deleted)
-    print(f"Deleted: {len(to_be_deleted)}, Created: {len(to_be_created)}, Updated: {len(updated)}")
+    print(f"Deleted: {len(to_be_deleted)}, Created: {len(to_be_created)}, Updated: {len(updated)}", flush=True)
