@@ -64,6 +64,14 @@ def deploy_function(
     while x < 3:
         function = None
         try:
+            if oidc:
+                print(
+                    f"Creating function using OIDC for function :{function_name} in project :{client.config.project}."
+                )
+            else:
+                print(
+                    f"Creating function using API key for function :{function_name} in project {client.config.project}"
+                )
             function = client.functions.create(
                 name=function_name,
                 file_id=file_id,
@@ -72,9 +80,14 @@ def deploy_function(
                 api_key=client._config.api_key if not oidc else None,
                 owner=owner,
             )
-            success = cdf.await_function_deployment(client, function, 900)
+            success, function_object = cdf.await_function_deployment(client, function, 900)
             if not success:
+                if function_object is not None:
+                    print(f"Error while deploying function {function_name} and function_id :{function_object.id}")
+                    print(f"Error message :{function_object.error.message}")
+                    print(f"Error stack trace :{function_object.error.trace}")
                 raise TimeoutError(f"Deployment of function with external id {function_name} timed out or failed.")
+
             print(
                 f"Function {function_name} (id: {function.id}) "
                 + f"successfully created in project {client.config.project}.",
